=============
How-To Guides
=============

These how-to guides provide step-by-step examples demonstrating 
some of MaDDG's key functionality.

.. toctree::
    :maxdepth: 1
    :caption: Contents:

    how_to_guides/example_1-propagate-satellite
    how_to_guides/example_2-observe-satellite
    how_to_guides/example_3-sensor-collections
    how_to_guides/example_4-satellite-maneuvers
    how_to_guides/example_5-launching-simulations